#!/bin/bash

set -e

P=zstd
V=1.4.4
B=1

[ -f $P-$V.tar.gz ] || wget -O $P-$V.tar.gz https://github.com/facebook/$P/archive/v$V.tar.gz
[ -f ../build/cmake/CMakeLists.txt ] || tar -C .. -xzf $P-$V.tar.gz --xform s,$P-$V,.,

D=$PWD

export MAINTAINER=JuergenFischer

#
# run batch file and source environment changes
#
fetchenv() {
	local IFS
	IFS=
	batch=$1	
	shift
	srcenv=$(mktemp /tmp/srcenv.XXXXXXXXXX)
	dstenv=$(mktemp /tmp/dstenv.XXXXXXXXXX)
	diffenv=$(mktemp /tmp/diffenv.XXXXXXXXXX)
	cmd.exe /c set >$srcenv
	cmd.exe /c call `cygpath -w $batch` "$@" \>nul 2\>nul \& set >$dstenv
	diff -u $srcenv $dstenv | sed -f $D/envdiff.sed >$diffenv
	. $diffenv
	PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
	rm -f $srcenv $dstenv $diffenv
}

[ -d "$OSGEO4W_REP" ]

for ARCH in x86_64 x86; do
	export ARCH

	(
		case "$ARCH" in
		x86)
			export OSGEO4W_ROOT="C:/OSGeo4W"
			export CMAKEGEN="Visual Studio 14 2015"
			VCARCH=x86
			;;

		x86_64)
			export OSGEO4W_ROOT="C:/OSGeo4W64"
			export CMAKEGEN="Visual Studio 14 2015 Win64"
			VCARCH=x64
			;;

		*)
			echo "Unsupported arch $ARCH" >&2
			exit 1
			;;
		esac

		fetchenv $OSGEO4W_ROOT/bin/o4w_env.bat
		fetchenv /c/Program\ Files*/Microsoft\ Visual\ Studio\ 14.0/VC/vcvarsall.bat $VCARCH

		export PATH="/c/Program Files/CMake/bin:/bin:$PATH"

		mkdir -p build-$ARCH
		cd build-$ARCH
	
		cmake -G "$CMAKEGEN" \
			-D CMAKE_INSTALL_PREFIX=../install-$ARCH \
			../../build/cmake

		cd ..
		for i in ZERO_CHECK ALL_BUILD INSTALL; do
			cmake --build build-$ARCH --target $i --config Release
		done

		export R=$OSGEO4W_REP/$ARCH/release/$P

		mkdir -p $R/$P-{devel,bin} 

		cat <<EOF >$R/setup.hint
sdesc: "Zstandard Long Range Match Finder (runtime)"
ldesc: "Zstandard Long Range Match Finder (runtime)"
Maintainer: JuergenFischer
category: Libs
requires: msvcrt2015
external-source: zstd
EOF

		cat <<EOF >$R/$P-devel/setup.hint
sdesc: "Zstandard Long Range Match Finder (development; VC2015)"
ldesc: "Zstandard Long Range Match Finder (development; VC2015)"
Maintainer: $MAINTAINER
category: Libs
requires: zstd
external-source: zstd
EOF

		cat <<EOF >$R/$P-bin/setup.hint
sdesc: "Zstandard Long Range Match Finder (binary)"
ldesc: "Zstandard Long Range Match Finder (binary)"
Maintainer: $MAINTAINER
category: Libs
requires: zstd
EOF

		cp ../LICENSE $R/$P-$V-$B.txt
		cp ../LICENSE $R/$P-devel/$P-devel-$V-$B.txt
		cp ../LICENSE $R/$P-bin/$P-bin-$V-$B.txt

		tar -C .. -cjf $R/$P-$V-$B-src.tar.bz2 \
			osgeo4w/package.sh \
			osgeo4w/envdiff.sed

		tar -C install-$ARCH -cjf $R/$P-$V-$B.tar.bz2 \
			bin/zstd.dll

		tar -C install-$ARCH -cjf $R/$P-devel/$P-devel-$V-$B.tar.bz2 \
			lib \
			include

		tar -C install-$ARCH -cjf $R/$P-bin/$P-bin-$V-$B.tar.bz2 \
			--exclude bin/zstd.dll \
			bin
	)
done
